dm: treewide: Rename ofdata_to_platdata() to of_to_plat()

This name is far too long. Rename it to remove the 'data' bits. This makes
it consistent with the platdata->plat rename.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/drivers/pci/pcie_xilinx.c b/drivers/pci/pcie_xilinx.c
index 7aaee77..00879a2 100644
--- a/drivers/pci/pcie_xilinx.c
+++ b/drivers/pci/pcie_xilinx.c
@@ -129,7 +129,7 @@
 }
 
 /**
  * pcie_xilinx_ofdata_to_platdata() - Translate from DT to device state
  * @dev: A pointer to the device being operated on
  *
  * Translate relevant data from the device tree pertaining to device @dev into
@@ -138,7 +138,7 @@
  *
  * Return: 0 on success, else -EINVAL
  */
-static int pcie_xilinx_ofdata_to_platdata(struct udevice *dev)
+static int pcie_xilinx_of_to_plat(struct udevice *dev)
 {
 	struct xilinx_pcie *pcie = dev_get_priv(dev);
 	struct fdt_resource reg_res;
@@ -174,6 +174,6 @@
 	.id			= UCLASS_PCI,
 	.of_match		= pcie_xilinx_ids,
 	.ops			= &pcie_xilinx_ops,
-	.ofdata_to_platdata	= pcie_xilinx_ofdata_to_platdata,
+	.of_to_plat	= pcie_xilinx_of_to_plat,
 	.priv_auto	= sizeof(struct xilinx_pcie),
 };
@@ -129,7 +129,7 @@
 
 /**
- * pcie_xilinx_ofdata_to_platdata() - Translate from DT to device state
+ * pcie_xilinx_of_to_plat() - Translate from DT to device state
  * @dev: A pointer to the device being operated on
  *